$\newcommand{\mvs}{\vspace{2.5cm}\\}$
$\newcommand{\mvv}{\vspace{4.0cm}\\}$
$\newcommand{\expt}{\textrm{E}}$
$\newcommand{\pr}{\textrm{Pr}}$
$\newcommand{\logn}{\textrm{ln}}$
$\newcommand{\var}{\textrm{Var}}$
$\newcommand{\RR}{\mathrm{I\!R\!}}$

# Risk-free and risky assets
Financial markets deal with two kinds of investments, *risk-free* and *risky*. 
To deposit money into a bank account for a fixed period with known interest rate is a 
typical example of an investment which is risk-free. To buy shares of (say) RBS is a 
risky investment. We will consider risk-free investment (via the money market) before 
examining a particular type of investment with a random return -- an **option**. 

## Risk-free investment / money market
Consider a bank offering a positive *interest rate* $r$  **per annum** for both borrowing and lending. 
The way of compounding your interest must be well defined. Suppose that $B_0$  invested/deposited  at time $0$. 

For **simple compounding**: after 1 year we get a return of
\[
B_{0}+B_{0}r=B_{0}(1+r).
\]
After 2 years we get a return of 
\[
(1+r)B_{0}+(1+r)B_{0}r = B_{0}(1+2r+r^{2}) = B_{0}(1+r)^{2}.
\]
Hence after $T$ years we get a **return** of $B_{0}(1+r)^{T}$. Note that 
the **total accrued interest** is $B_{0}(1+r)^{T} - B_0$.

**Compounding does not have to be per annum.** Suppose that compounding is semi-annually so that 
$\frac{r}{2}$ is the interest rate for a half-year (1 period is now 6 months). In this case, after 6 months we get
\[
B_{0}\left(1+\frac{r}{2}\right).
\]
After 1 year ($=12$ months $=2$ periods) we get a return of
\[
B_{0}\left(1+\frac{r}{2}\right)^{2}.
\]
After $T$ years ($=2T$ periods) we get a return of
\[
B_{0}\left(1+\frac{r}{2}\right)^{2T}.
\]

\subsubsection*{Definition 1.1 (periodic compounding)}

Suppose that compounding is every $\frac{1}{n}\times$year. The interest rate per period is $\frac{r}{n}$ and after $T$ years we get 
a return of
\[
B_{0}\left(1+\frac{r}{n}\right)^{nT}. %\to B_{0}e^{rT} \quad \textrm{as $n\to \infty$}.
\]
The total accrued interest is $B_0 (1+r/n)^{nT} - B_0$. 

We might wonder what happens as the frequency at which compounding takes place increases. 
This notion leads to the following definition.

\subsubsection*{Definition 1.2 (continuous compounding)}

Note that a characterisation of the exponential function is 
\[
e^x = \lim_{n\rightarrow \infty} \left(1+\frac{x}{n}\right)^n.
\]
Hence, we may deduce that
\[
B_{0}\left(1+\frac{r}{n}\right)^{nT} \to B_0 e^{rT} \qquad \text{as $n\to\infty$}.
\]
Formally, if compounding is continuous, the interest rate is $r$ p.a. then $B_0$ invested in the 
bank for $T$ years gives a return of
\[
B_0\,e^{rT}.
\]
The total accrued interest with continuous compounding is then $B_0\,e^{rT} - B_0$.
 
\subsubsection*{Example 1.1}
Suppose that $B_{0}$ is invested into a bank account for one year with rate $r$ per annum. Given the choice 
between annual or semi-annual compounding, which do you choose?

\subsubsection*{\emph{Solution}}
\emph{Since}
\[
\left(1+\frac{r}{2}\right)^{2} > (1+r)
\]
\emph{we choose semi-annual compounding!}

\subsubsection*{Example 1.2}
Suppose that $r=5\%$ per annum with semi-annual compounding. How much should you invest to give 
an \emph{accrued interest / net profit} of 2000 after 18 months? Now assume that 
$B_{0} = 1000$. How many months until your net profit is 280? 

\subsubsection*{\emph{Solution}}
\emph{1 time period is 6 months with interest rate 0.025 per period. 18 months is 3 time periods so 
we require $B_0$ such that}
\begin{align*}
B_{0}\left(1+0.025\right)^{3}-B_{0} &= 2000\\
\Rightarrow B_{0}(1.0769-1) &= 2000\\
\Rightarrow B_{0}&=26010.97.
\end{align*}
\emph{Now assume that $B_0 = 1000$. Let $T$ be the time in months until we get a net profit of 280. We 
therefore require $T$ such that}
\begin{align*}
1000\left(1+0.025\right)^{T/6} - 1000 &=280\\
\Rightarrow (1.025)^{T/6} &= 1.28\\
\Rightarrow \frac{T}{6}\ln(1.025) &= \ln(1.28)\\
\Rightarrow T&=60.
\end{align*}
\subsection{Investments with random returns}
For example, investing $\pounds 1$ on a national lottery ticket. The return is 0, $\pounds 10$, etc 
with ever diminishing probabilities.

Suppose that we invest $B_{0}$ at time $0$ and denote the return by $B_{T}$. For random returns, $B_{T}$ 
is of course, a random variable. To choose between investments, we might consider the expected return of each. 
For $B_{T}\sim$ discrete with possible values $b_{1}, b_{2},\ldots$ and probabilities $p_{j}=Pr(B_{T}=b_{j})$ 
recall that
\[
E(B_{T}) = \sum_{j}b_{j}p_{j}.
\]
For $B_{T}\sim$ continuous with support $\mathcal{S}$ and probability density function (pdf) $f_{B_{T}}(b)$ we have 
\[
E(B_{T}) = \int_{\mathcal{S}}b\,f_{B_{T}}(b)\,db.
\]  
We may also calculate the variance of $B_T$ via
\[
Var(B_T)=E(B_T^2)-[E(B_T)]^2.
\]

As a trivial example, consider
\begin{enumerate}
\item $B_{T}\sim \textrm{Gamma}(2,0.1)$,
\item $B_{T}^{*}\sim \textrm{Bin}(100,0.2)$.
\end{enumerate}
Plainly, $E(B_{T})=E(B_{T}^{*})=20$. Which investment do we prefer? We could use the variance 
as the criterion:
\[
Var(B_{T})=200, \qquad Var(B_{T}^{*})=16.
\]
We therefore choose investment 2.

\subsubsection*{Example 1.3}
Suppose that your return follows a binomial $\textrm{Bin}(10,0.25)$ distribution, 
left truncated at 2 and right truncated at 8 so that the return takes values 
$2,3,\ldots ,8$. What is the expected return? 

\subsubsection*{\emph{Solution}}
\emph{Let $B_{T}\sim \textrm{Bin}(10.0.25)$ and let $\tilde{B}_{T}$ denote the truncated version. 
We have that}
\[
Pr(B_{T}=j) = p_{j} = \phantom{1}^{10}C_{j}\left(\frac{1}{4}\right)^{j}\left(\frac{3}{4}\right)^{10-j}, \quad j=0,1,2,\ldots,10
\]
\emph{and}
\begin{align*}
Pr(\tilde{B}_{T}=j) = \tilde{p}_{j} &= Pr(B_{T}=j |2\leq B_{T}\leq 8) \qquad j=2,3,\ldots ,8\\
&=\frac{p_{j}}{Pr(2\leq B_{T}\leq 8)} \qquad j=2,3,\ldots ,8\\
&=\frac{p_{j}}{0.756}\qquad j=2,3,\ldots ,8
\end{align*}
\emph{Hence we obtain the expected return as}
\[
E(\tilde{B}_{T}) = \sum_{j=2}^{8}j\tilde{p}_{j} = 3.058.
\]

\emph{Comment: Note that $\tilde{p}_j = p_{j}/k$ where the constant $k$ is simply the probability 
of being (strictly) between the truncation limits. That is, the role of $k$ ensures that the $\tilde{p}_j$ sum to 1.}

%\subsubsection*{Example 1.4}
%You are dealing with an investment and you know that your return $B_T$ at time $T$ is random. Calculate your 
%expected (averaged) return if the distribution of $B_T$ is Exponential with parameter $\lambda = 4$, 
%left-truncated at 2 and right-truncated at 7.
%
%\subsubsection*{\emph{Solution}}
%\emph{Take $B_{T} \sim Exp(\lambda)$ with $\lambda = 4$. The density is} 
%\[
%f(b)=4\,e^{-4b}, \quad b > 0 \qquad (f(b)=0, \ b \leq 0)
%\] 
%\emph{and the distribution function (df) is} 
%\[
%F(b)=Pr(B_{T}\leq b) = 1-e^{-4b}, \quad b > 0.
%\]
%\emph{Now we deal with the truncated r.v. $\tilde{B}_{T}$. 
%Since its df} 
%\[
%{\tilde F}(b)=
%Pr(\tilde{B}_{T} \leq b) = 0 \quad b<2 \quad \textrm{\emph{and $=1$ for $b>7$}}, 
%\]
%\emph{it follows that for $b \in [2,7]$ we have} 
%\[
%{\tilde F}(b)= Pr(B_{T} \leq b|2 \leq B_{T} \leq 7)=(F(b)-F(2))/k, 
%\]
%\emph{where  $k = Pr(2 \leq B_{T} \leq 7)=F(7)-F(2)=e^{-8}-e^{-28}$.}  
%\emph{Now we find the density  $\tilde f$ of $\tilde{B}_{T}$ as the derivative of $\tilde F$,  ${\tilde f}(b)= {\tilde F}'(b) = f(b)/k$ for $b \in [2,7].$ 
%The expected return is} 
%\[
%E(\tilde{B}_{T}) = \int_2^7 b\,{\tilde f}(b)db = \int_2^7 b\,(f(b)/k)db.
%\]
%\emph{After integrating we find the following:} 
%\[
%E(\tilde{B}_{T}) = \frac{2.25 \times e^{-8} - 7.25 \times e^{-28}}{e^{-8}-e^{-28}}=\frac
%{e^{-8}[2.25  - 7.25 \times e^{-20}]}{e^{-8}[1-e^{-20}]} \approx 2.25. 
%\]

\subsubsection*{Example 1.4}

Let $X\sim \textrm{N}(4,4)$ and define $\tilde{X}$ by two-sided truncation, at the left at 0 and at the right at 10. 
Let $\tilde{F}(x)=Pr(\tilde{X}\leq x)$.
\begin{itemize}
\item[(a)] Show that 
\[
\tilde{F}(x)=\frac{\Phi\left(\frac{x-4}{2}\right)-\Phi\left(-2\right)}{\Phi\left(3\right)-\Phi\left(-2\right)}, \quad x\in (0,10)
\]  
where $\Phi(\cdot)$ is the distribution function (d.f.) of a $\textrm{N}(0,1)$ random variable.
\item[(b)] What is $\tilde{F}(x)$ for (i) $x\leq 0$ and (ii) $x\geq 10$?\\
\item[(c)] The return of a trader is a random variable $B_T$ such that $B_T =1$ if $\tilde{X}\leq 4$ and $B_T =4$ if $\tilde{X}>4$. 
Calculate $E(B_T)$.
\end{itemize}

\subsubsection*{\emph{Solution}}
\emph{
\begin{itemize}
\item[(a)] We have that
\begin{eqnarray*}
\tilde{F}(x) &=& Pr(X\leq x | 0\leq X \leq 10), \qquad x\in (0,10)\\
&=&\frac{Pr([X\leq x]\cap [0\leq X\leq10])}{Pr(0\leq X\leq10)}\\
&=&\frac{Pr(0\leq X\leq x)}{Pr(0\leq X\leq10)}\\
&=&\frac{Pr(X\leq x)-Pr(X\leq 0)}{Pr(X\leq 10)-Pr(X\leq 0)}\\ 
&=&\frac{\Phi\left(\frac{x-4}{2}\right)-\Phi\left(-2\right)}{\Phi\left(3\right)-\Phi\left(-2\right)} \qquad\textrm{(after centering and normalising),}
\end{eqnarray*} 
as required.
\item[(b)] For $x\leq 0$, $\tilde{F}(x)=0$ and for $x\geq 10$, $\tilde{F}(x)=1$.
\item[(c)] We have that $Pr(\tilde{X}\leq 4)=\tilde{F}(4)=(\Phi(0)-\Phi(-2))/(\Phi(3)-\Phi(-2))=0.489$. Now 
$Pr(\tilde{X}>4)=1-\tilde{F}(4)=0.511$. Therefore
\[
E(B_T)=1\times 0.489 + 4\times 0.511 = 2.53.
\]
\end{itemize}
}

\emph{Comment: the pdf of $\tilde{X}$, $\tilde{f}(x)$ can be found by differentiating the cdf $\tilde{F}(x)=\Phi(\frac{x-4}{2})$.  
We obtain
\[
\tilde{f}(x) = \frac{d}{dx} \tilde{F}(x) = \frac{f(x)}{k}, \qquad x\in (0,10)
\]
where the constant $k$ is $Pr(X\leq 10)-Pr(X\leq 0)$. Hence we see that the role of this constant is to ensure 
that $\tilde{f}(x)$ integrates to 1 over the range $(0,10)$.}

%\newpage
\subsection{Options}
We can think of a \emph{financial instrument} as cash, or a contractual right to receive or deliver cash 
or another financial instrument. Options are a particular type of financial instrument with a random 
payoff. They are usually traded on stock exchanges (e.g. NYSE). The stock market is the trading of all 
securities listed listed on exchanges. 

Before examining a particular class of options, we will take a look at a simpler instrument, the futures contract. 
Note that all financial instruments in this Section are \emph{contracts} which have two positions: the buyer (also holder / long position) vs the seller (also writer / short position) \emph{of the contract}.  

\subsubsection{Futures contracts}

\subsubsection*{Definition 1.3 (futures contract)}
A \emph{futures contract} is an agreement between two parties to buy/sell one share of stock 
for a \emph{strike price} $K$ at \emph{maturity time} $T$. 
\begin{itemize}
\item The buyer/holder (long position) has payoff
\[
g(S_T) = S_{T}-K
\]
where $S_T$ is the market value or spot price of the stock at time $T$.
\item The seller/writer (short position) has payoff
\[
-g(S_T) = K-S_{T}.
\]
\end{itemize}
These linear payoffs can be easily sketched against $S_T$.

\subsubsection{European options}
Again, a contract between two parties. The holder of the option has the right to do 
something involving a share of stock. What it is they can do depends on the type of option. 
The holder does not have to exercise their right -- they have a choice (hence 
the terminology \emph{option}!) We will look at two types of option here.

Throughout, we will assume that neither contract position owns the share of stock 
involved in the option at any time. To this end, we can view the option simply as a 
financial instrument that yields a payoff at a set time.

\newpage

\subsubsection*{Definition 1.4 (European call option)}
A \emph{European call option} (ECO) gives the holder of the option the right but not the obligation 
to \emph{buy} one share of stock for a strike price $K$ at maturity time $T$.   
\begin{itemize}
\item The buyer/holder (long position) has payoff
\[
g(S_T) = \textrm{max}(0,S_{T}-K)=(S_{T}-K)^{+}\,.
\]
\item The seller/writer (short position) has payoff
\[
-g(S_T) = -\textrm{max}(0,S_{T}-K)=\textrm{min}(0,K-S_T)\,.
\]
\end{itemize}
Note that there is a cost for being the holder of an option. The holder must pay 
the writer an amount, say $C_{0}$ upon entering the contract. 
\begin{itemize}
\item The buyer/holder (long position) realises a \emph{net profit}
\[
N(S_T) = g(S_T)-C_{0}=(S_{T}-K)^{+}-C_{0}\,.
\]
\item The seller/writer (short position) realises a \emph{net profit}
\[
-N(S_T)=C_{0}-g(S_T) = C_{0}+\textrm{min}(0,K-S_T)\,.
\]
\end{itemize}

\emph{Thought experiment: The current price of stock is 15. 
suppose I hold one ECO with maturity in one minute, and strike price $K=10$. You are the writer 
of the contract. One minute is up and the stock price has risen to 16. I immediately exercise my 
right by buying one share from you for 10 and I then immediately sell for the market value of 16. I get 
a payoff of $16-10 = 6$. You, on the other hand (at time $T=$ one minute) have to buy one share for 16 and 
then immediately sell to me for the strike price of 10. Your payoff is $10-16=-6$. Using the payoff function:
\[
\textrm{Aamir's payoff:} \qquad g(S_T) = \textrm{max}(0, S_T -10) = \textrm{max}(0, 16-10) = 6.
\]  
Of course, the payoff isn't the full story. Suppose I pay you 8 up front so that I can hold the option. 
In this case, my net profit is $6-8 = -2$ and your net profit is $-6+8=2$. 
}

\newpage

\subsubsection*{Definition 1.5 (European put option)}
A \emph{European put option} (EPO) gives the holder of the option the right but not the obligation 
to \emph{sell} one share of stock for a strike price $K$ at maturity time $T$. 
\begin{itemize}
\item The buyer/holder (long position) has payoff
\[
g(S_T) = \textrm{max}(0,K-S_{T})=(K-S_{T})^{+}\,.
\]
\item The seller/writer (short position) has payoff
\[
-g(S_T) = -\textrm{max}(0,K-S_{T})=\textrm{min}(0,S_T-K)\,.
\]
\end{itemize}
As with the ECO, there is a cost to acquiring the put option. The holder must pay 
the writer an amount, say $P_{0}$ upon entering the contract.

Plots of the payoff functions for the ECO and EPO (for both holder and writer positions) can be found in Figure~\ref{fig:figOPT}. 
There are 4 plots since we have two options each with a possible two positions (and each combination gives a different payoff).


\begin{figure}[h]
\begin{center}
\includegraphics[width=6cm,angle=270]{opt1-eps-converted-to.pdf}\\
\includegraphics[width=6cm,angle=270]{opt2-eps-converted-to.pdf}
\end{center}
\caption{Payoffs for the holder of the ECO (top left), writer of the ECO (top right), holder of the EPO (bottom left) and writer of the EPO (bottom right). All assume a strike price of $K=5$.}\label{fig:figOPT}
\end{figure}



\subsubsection*{Definition 1.6 (European contingent claim)}
A \emph{European contingent claim} (ECC) with payoff pattern $g(\cdot)$ is any financial contract 
which gives the holder $g(S_T)$ at time $T$. For example, you could have an ECC consisting 
of two ECOs with different strike prices.

\subsubsection*{Example 1.5}
A \emph{strip} consists of a long position in one call and two puts with the same strike price and maturity 
time. A \emph{strap} consists of a long position in two calls and one put with the same strike price and maturity 
time. Write down the payoffs of these options explicitly as functions of $S_{T}$ and sketch them.

\subsubsection*{\emph{Solution}}
\emph{For the strip, we have that
\[
g(S_T)=(S_{T}-K)^{+}+2(K-S_{T})^{+}.
\]
Or explicitly,
\[
g(S_T)=\left\{\begin{array}{cc}
2(K-S_{T}), & S_{T}\leq K\\
(S_{T}-K), & S_{T}> K
\end{array}\right.
\]
For the strap, we have that
\[
g(S_T)=2(S_{T}-K)^{+}+(K-S_{T})^{+}.
\]
Or explicitly,
\[
g(S_T)=\left\{\begin{array}{cc}
(K-S_{T}), & S_{T}\leq K\\
2(S_{T}-K), & S_{T}> K
\end{array}\right.
\]
The payoffs are easily sketched. See Figure~\ref{fig:figSS} for the case when $K=5$.
}

\begin{figure}[h]
\begin{center}
\includegraphics[width=6cm,angle=270]{stripstrap-eps-converted-to.pdf}
\end{center}
\caption{Payoffs for the holder of the strip (left) and strap (right). Both assume a strike price of $K=5$.}\label{fig:figSS}
\end{figure}


\subsubsection{Arbitrage}
\subsubsection*{Definition 1.7 (arbitrage opportunity)}
An \emph{arbitrage opportunity} is to make a risk free profit from zero endowment. We will 
assume that the market offers no arbitrage opportunities. In particular, if two portfolios 
(that is, a combination of a position in stocks and the money market) have the same payoff, 
then their fair prices must coincide. This leads to the following result.

%\clearpage

\subsubsection{European put-call-parity}
Define the following:
\begin{itemize}
\item $S_{0}$ is the stock price at time $0$,
\item $r$ is the continuously compounded risk-free interest rate (per annum),
\item $C_{0}$ is the fair price of 1 ECO, with maturity $T$ and strike price $K$ 
written on 1 share of stock,
\item $P_{0}$ is the fair price of 1 EPO, with maturity $T$ and strike price $K$ 
written on 1 share of the same stock as the ECO.
\end{itemize}

\subsubsection*{Result 1.1 (European put-call-parity)}

Under the assumption of no arbitrage, the put-call-parity is
\[
P_{0}+S_{0} = C_{0}+e^{-rT}K\,.
\]

\vspace{0.2cm}

\textbf{Derivation}:

\vspace{0.2cm}

Consider two trading positions A and B:
\begin{itemize}
\item Position A: buy one put option with maturity $T$ and strike price $\pounds K$ for $\pounds P_{0}$.
Buy one share of stock.
\item Position B: Buy one call option with maturity $T$ and strike price $\pounds K$ for $\pounds C_{0}$. Invest 
$\pounds Ke^{-rT}$ in the bank.
\end{itemize}

The total cost for setting position A is $P_{0}+S_{0}$.\\
The total cost for setting position B is $C_{0}+Ke^{-rT}$,

Let $V_{T}(\cdot)$ denote the portfolio value at time $T$. Consider first position A. 
At time $T$ if $S_{T}\leq K$ the put is exercised yielding $(K-S_{T})$ and our stock has the value $S_{T}$. If 
$S_{T}>K$ then our put is worthless but our stock is worth $S_{T}$. Hence the value of position A at time $T$ is
\[
V_{T}(A)=\left\{
\begin{array}{cc}
S_{T}+(K-S_{T}), & S_{T}\leq K\\
S_{T}, & S_{T} > K
\end{array}\right.
\]
Hence
\[
V_{T}(A)=\left\{
\begin{array}{cc}
K, & S_{T}\leq K\\
S_{T}, & S_{T} > K
\end{array}\right. = \max(K,S_{T})
\]
Now consider position B. If $S_{T}\leq K$ at time $T$, then the call is worthless but we realise $Ke^{-rT}e^{rT}=K$ from the bank. If $S_{T}>K$ then we exercise the call and get $(S_{T}-K)$ and realise $K$ from the bank. Hence the value of position B at time $T$ is
\[
V_{T}(B)=\left\{
\begin{array}{cc}
K, & S_{T}\leq K\\
(S_{T}-K)+K, & S_{T} > K
\end{array}\right.
\]
Hence
\[
V_{T}(B)=\left\{
\begin{array}{cc}
K, & S_{T}\leq K\\
S_{T}, & S_{T} > K
\end{array}\right. = \max(K,S_{T})
\] 
So both positions have the same value at $T$ and for no arbitrage it must be that both positions cost the same to set up i.e. $P_{0}+S_{0}=C_{0}+Ke^{-rT}$ and the put-call parity holds.

\subsubsection*{Example 1.6}
Suppose that
\[
P_{0}+S_{0} < C_{0}+e^{-rT}K\,.
\]
Describe a trading strategy to exploit this scenario and realise an arbitrage opportunity.

\subsubsection*{\emph{Solution}}
\emph{At time $t=0$, sell 1 ECO and borrow $e^{-rT}K$ from the bank. Use the amount obtained at time $t=0$ 
to buy 1 EPO and 1 share of stock. We get in our pocket at time $t=0$ the amount
\[
C_{0}+e^{-rT}K-P_{0}-S_{0}>0
\]
using the inequality given above. Now, at time $t=T$, our payoff is $\max(K,S_{T})-\max(K,S_{T})=0$ so our 
net profit is $C_{0}+e^{-rT}K-P_{0}-S_{0}>0$. We have realised an arbitrage opportunity!
}

\end{document}

\newpage

\subsection*{Section quiz}

\begin{itemize}
\item[\textbf{Q1}] 1 pound invested in a bank with p.a. interest rate $r$ 
and semi-annual compounding gives a return, after 1 year, of
\begin{itemize}
\item[\textbf{(a)}] $e^{rT}$
\item[\textbf{(b)}] $(1+r)^{2}$
\item[\textbf{(c)}] $(1+r/2)^{2}$ 
\item[\textbf{(d)}] $(1+r/2)$ 
\end{itemize}

\item[\textbf{Q2}] Tick all that apply. In the context of an option, 
the trader in the \emph{long position} is also known as
\begin{itemize}
\item[\textbf{(a)}] the writer of the option. 
\item[\textbf{(b)}] the buyer of the option.
\item[\textbf{(c)}] the seller of the option.
\item[\textbf{(d)}] the holder of the option.
\end{itemize}

\item[\textbf{Q3}] A European call option (with strike $K$ and maturity $T$) gives the \emph{holder} 
\begin{itemize}
\item[\textbf{(a)}] the right but not the obligation to sell 1 share at $T$ for $K$. 
\item[\textbf{(b)}] the right but not the obligation to buy 1 share at $T$ for $K$.
\item[\textbf{(c)}] the obligation to buy 1 share at $T$ for $K$.
\end{itemize}

\item[\textbf{Q4}] The \emph{writer} of a European put option (with strike $K$ and maturity $T$) has payoff  
\begin{itemize}
\item[\textbf{(a)}] max$(0,K-S_{T})$ 
\item[\textbf{(b)}] min$(0,S_{T}-K)$
\item[\textbf{(c)}] min$(0,K-S_{T})$
\end{itemize}
\end{itemize}

